import Config

config :live_beats, :files,
  uploads_dir: Path.expand("../priv/uploads", __DIR__),
  host: [scheme: "http", host: "localhost", port: 4000],
  server_ip: "127.0.0.1",
  hostname: "localhost",
  transport_opts: []

config :live_beats, :github,
  client_id: System.fetch_env!("LIVE_BEATS_GITHUB_CLIENT_ID"),
  client_secret: System.fetch_env!("LIVE_BEATS_GITHUB_CLIENT_SECRET")

# Configure your database
config :live_beats, LiveBeats.Repo,
  username: "postgres",
  password: "postgres",
  database: "live_beats_dev",
  hostname: "localhost",
  show_sensitive_data_on_connection_error: true,
  pool_size: 10

# Configure your replica database
config :live_beats, LiveBeats.ReplicaRepo,
  username: "postgres",
  password: "postgres",
  database: "live_beats_dev",
  hostname: "localhost",
  show_sensitive_data_on_connection_error: true,
  pool_size: 10,
  priv: "priv/repo"

# For development, we disable any cache and enable
# debugging and code reloading.
#
# The watchers configuration can be used to run external
# watchers to your application. For example, we use it
# with esbuild to bundle .js and .css sources.
config :live_beats, LiveBeatsWeb.Endpoint,
  # Binding to loopback ipv4 address prevents access from other machines.
  # Change to `ip: {0, 0, 0, 0}` to allow access from other machines.
  http: [ip: {127, 0, 0, 1}, port: 4000],
  debug_errors: true,
  code_reloader: true,
  check_origin: false,
  watchers: [
    # Start the esbuild watcher by calling Esbuild.install_and_run(:default, args)
    esbuild: {Esbuild, :install_and_run, [:default, ~w(--sourcemap=inline --watch)]},
    tailwind: {Tailwind, :install_and_run, [:default, ~w(--watch)]}

    # npx: [
    #    "tailwindcss",
    #    "--input=css/app.css",
    #    "--output=../priv/static/assets/app.css",
    #    "--postcss",
    #    "--watch",
    #    cd: Path.expand("../assets", __DIR__)
    #  ]
  ]

# ## SSL Support
#
# In order to use HTTPS in development, a self-signed
# certificate can be generated by running the following
# Mix task:
#
#     mix phx.gen.cert
#
# Note that this task requires Erlang/OTP 20 or later.
# Run `mix help phx.gen.cert` for more information.
#
# The `http:` config above can be replaced with:
#
#     https: [
#       port: 4001,
#       cipher_suite: :strong,
#       keyfile: "priv/cert/selfsigned_key.pem",
#       certfile: "priv/cert/selfsigned.pem"
#     ],
#
# If desired, both `http:` and `https:` keys can be
# configured to run both http and https servers on
# different ports.

# Watch static and templates for browser reloading.
config :live_beats, LiveBeatsWeb.Endpoint,
  live_reload: [
    patterns: [
      ~r"priv/static/.*(js|css|png|jpeg|jpg|gif|svg)$",
      ~r"priv/gettext/.*(po)$",
      ~r"lib/live_beats_web/(live|views)/.*(ex)$",
      ~r"lib/live_beats_web/templates/.*(eex)$"
    ]
  ]

# Do not include metadata nor timestamps in development logs
config :logger, :console, format: "[$level] $message\n"

# Set a higher stacktrace during development. Avoid configuring such
# in production as building large stacktraces may be expensive.
config :phoenix, :stacktrace_depth, 20

# Initialize plugs at runtime for faster development compilation
config :phoenix, :plug_init_mode, :runtime
